NetworkMetric class

Constructors

NetworkMetric({required String id, required String url, required String method, required int statusCode, required Duration duration, required DateTime timestamp, int? requestSize, int? responseSize, Map<String, dynamic>? metadata, NetworkTiming? timing, bool fromCache = false, String? priority, String? initiator})
const
NetworkMetric.fromMap(Map<String, dynamic> map)
factory

Properties

bandwidthKBps double?
Bandwidth in KB/s based on response size and download time.
no setter
duration Duration
final
fromCache bool
Whether this request was served from cache.
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
initiator String?
Initiator of the request (navigation, script, user, etc.).
final
isError bool
no setter
isSuccess bool
no setter
metadata Map<String, dynamic>?
final
method String
final
priority String?
Request priority (low, medium, high).
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
requestSize int?
final
responseSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp DateTime
final
timeToFirstByteMs int?
Time to first byte from timing breakdown.
no setter
timing NetworkTiming?
Detailed timing breakdown for the request.
final
url String
final

Methods

copyWith({String? id, String? url, String? method, int? statusCode, Duration? duration, DateTime? timestamp, int? requestSize, int? responseSize, Map<String, dynamic>? metadata, NetworkTiming? timing, bool? fromCache, String? priority, String? initiator}) NetworkMetric
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited